summaryrefslogtreecommitdiff
path: root/flexdef.h
diff options
context:
space:
mode:
authorJohn Millaway <john43@users.sourceforge.net>2003-04-01 01:51:38 +0000
committerJohn Millaway <john43@users.sourceforge.net>2003-04-01 01:51:38 +0000
commitf6757b47e901c266b573a8d85a9a2ac77149c85e (patch)
treec473ef416cb8af4c3904fab1ae89ca97bd4979ba /flexdef.h
parent85847d998a69dc8c89c6c7703349d07980fadb17 (diff)
Renamed some internal variables.
Diffstat (limited to 'flexdef.h')
-rw-r--r--flexdef.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/flexdef.h b/flexdef.h
index facc266..b50bbd5 100644
--- a/flexdef.h
+++ b/flexdef.h
@@ -352,8 +352,8 @@
* C_plus_plus - if true (i.e., -+ flag), generate a C++ scanner class;
* otherwise, a standard C scanner
* reentrant - if true (-R), generate a reentrant C scanner.
* bison_bridge - if true (--bison-bridge), bison pure calling convention.
* bison_bridge_locations - if true (--bison-locations), bison yylloc.
* long_align - if true (-Ca flag), favor long-word alignment.
* use_read - if true (-f, -F, or -Cr) then use read() for scanner input;
* otherwise, use fread().
@@ -380,7 +380,7 @@ extern int printstats, syntaxerror, eofseen, ddebug, trace, nowarn,
extern int interactive, caseins, lex_compat, posix_compat, do_yylineno;
extern int useecs, fulltbl, usemecs, fullspd;
extern int gen_line_dirs, performance_report, backing_up_report;
-extern int reentrant, bison_bridge, bison_bridge_locations;
+extern int reentrant, bison_bridge_lval, bison_bridge_lloc;
extern bool ansi_func_defs, ansi_func_protos;
extern int C_plus_plus, long_align, use_read, yytext_is_array, do_yywrap;
extern int csize;
@@ -352,8 +352,8 @@
* otherwise, a standard C scanner
* reentrant - if true (-R), generate a reentrant C scanner.
- * bison_bridge - if true (--bison-bridge), bison pure calling convention.
- * bison_bridge_locations - if true (--bison-locations), bison yylloc.
+ * bison_bridge_lval - if true (--bison-bridge), bison pure calling convention.
+ * bison_bridge_lloc - if true (--bison-locations), bison yylloc.
* long_align - if true (-Ca flag), favor long-word alignment.
* use_read - if true (-f, -F, or -Cr) then use read() for scanner input;